%define major		45
%define libname		%mklibname filezilla %{major}
%define develname	%mklibname filezilla -d

Name:		libfilezilla
Version:	0.48.1
Release:	%mkrel 1
Summary:	Small and modern C++ library for FileZilla
License:	GPLv2+
Group:		System/Libraries
URL:		https://lib.filezilla-project.org/
Source0:	https://download.filezilla-project.org/%{name}/%{name}-%{version}.tar.xz

BuildRequires:	doxygen
BuildRequires:	graphviz
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(nettle)

# needed for testsuite
BuildRequires:	locales-en
BuildRequires:	pkgconfig(cppunit)

%description
libfilezilla is a free, open source C++ library, offering some basic
functionality to build high-performing, platform-independent programs.
Some of the highlights include:

* A typesafe, multi-threaded event system that's very simple to use yet
  extremely efficient.
* Timers for periodic events.
* A datetime class that not only tracks timestamp but also their accuracy,
  which simplifies dealing with timestamps originating from different sources.
* Simple process handling for spawning child processes with redirected I/O.

#------------------------------------------------

%package -n	%{libname}
Summary:	Small and modern C++ library for FileZilla
Group:		System/Libraries
Requires:	%{name}-i18n >= %{version}

%description -n	%{libname}
libfilezilla is a free, open source C++ library, offering some basic
functionality to build high-performing, platform-independent programs.
Some of the highlights include:

* A typesafe, multi-threaded event system that's very simple to use yet
  extremely efficient.
* Timers for periodic events.
* A datetime class that not only tracks timestamp but also their accuracy,
  which simplifies dealing with timestamps originating from different sources.
* Simple process handling for spawning child processes with redirected I/O.

#------------------------------------------------

%package -n	%{develname}
Summary:	Development package for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
Header files for development with %{name}.

#------------------------------------------------

%package	i18n
Summary:	Translation files for %{name}
Group:		System/Libraries
BuildArch:	noarch

%description	i18n
This package contains translation files for %{name}.

#------------------------------------------------

%prep
%autosetup -p1

%build
%configure \
		--disable-static
%make_build
%__make -C doc html

%install
%make_install

# we don't want these
find %{buildroot} -name '*.la' -delete

%find_lang %{name}

%check
LC_ALL=en_US.UTF-8 \
%__make check

%files i18n -f %{name}.lang

%files -n %{libname}
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/%{name}.so.%{major}{,.*}

%files -n %{develname}
%doc AUTHORS ChangeLog NEWS README
%doc doc/doxygen-doc/*
%{_includedir}/%{name}/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc


%changelog
* Wed Jul 10 2024 daviddavid <daviddavid> 0.48.1-1.mga10
+ Revision: 2080548
- new version: 0.48.1

* Tue Jul 02 2024 daviddavid <daviddavid> 0.48.0-1.mga10
+ Revision: 2078767
- new version: 0.48.0
- now libmajor is 44

* Tue Apr 16 2024 daviddavid <daviddavid> 0.47.0-1.mga10
+ Revision: 2058031
- new version: 0.47.0 (mga#33103)
- now libmajor is 43

* Wed Feb 07 2024 daviddavid <daviddavid> 0.46.0-1.mga10
+ Revision: 2038228
- new version: 0.46.0
- now libmajor is 42

* Thu Oct 26 2023 daviddavid <daviddavid> 0.45.0-1.mga10
+ Revision: 2001919
- new version: 0.45.0
- now libmajor is 41

* Wed Apr 26 2023 daviddavid <daviddavid> 0.42.2-1.mga9
+ Revision: 1955054
- new version: 0.42.2
- now libmajor is 36

* Fri Feb 24 2023 daviddavid <daviddavid> 0.41.1-1.mga9
+ Revision: 1945199
- new version: 0.41.1
- now libmajor is 35

* Wed Jan 25 2023 daviddavid <daviddavid> 0.41.0-1.mga9
+ Revision: 1936077
- new version: 0.41.0
- now libmajor is 34

* Wed Jan 04 2023 daviddavid <daviddavid> 0.40.0-1.mga9
+ Revision: 1929904
- new version: 0.40.0
- library major is now 33

* Sat Oct 29 2022 kekepower <kekepower> 0.39.2-1.mga9
+ Revision: 1900005
- Update to version 0.39.2

* Sun Sep 11 2022 neoclust <neoclust> 0.38.1-1.mga9
+ Revision: 1886987
- New version 	0.38.1

* Fri Jun 17 2022 kekepower <kekepower> 0.37.2-1.mga9
+ Revision: 1864731
- Update to version 0.37.2

* Thu Mar 31 2022 umeabot <umeabot> 0.30.0-2.mga9
+ Revision: 1836972
- Mageia 9 Mass Rebuild

* Fri Jul 23 2021 neoclust <neoclust> 0.30.0-1.mga9
+ Revision: 1737464
- New version 0.30.0

* Thu May 06 2021 daviddavid <daviddavid> 0.28.0-1.mga9
+ Revision: 1721737
- new version: 0.28.0
- now libmajor is 13

* Wed Mar 17 2021 daviddavid <daviddavid> 0.27.1-1.mga9
+ Revision: 1704005
- new version: 0.27.1

* Wed Mar 10 2021 neoclust <neoclust> 0.27.0-1.mga9
+ Revision: 1700971
- New version 0.27.0
- New version 0.27.0

* Thu Feb 25 2021 daviddavid <daviddavid> 0.26.0-1.mga9
+ Revision: 1690649
- new version: 0.26.0
- now libmajor is 11

* Sun Nov 29 2020 luigiwalser <luigiwalser> 0.25.0-2.mga8
+ Revision: 1650424
- rebuild for nettle

* Tue Oct 20 2020 daviddavid <daviddavid> 0.25.0-1.mga8
+ Revision: 1637204
- new version: 0.25.0
- now libmajor is 10

* Wed Sep 02 2020 daviddavid <daviddavid> 0.24.1-1.mga8
+ Revision: 1620793
- new version: 0.24.1

* Mon Aug 24 2020 daviddavid <daviddavid> 0.24.0-1.mga8
+ Revision: 1618291
- new version: 0.24.0
- now libmajor is 9

* Tue Jul 14 2020 daviddavid <daviddavid> 0.23.0-1.mga8
+ Revision: 1606056
- new version: 0.23.0
- now libmajor is 8

* Tue May 12 2020 daviddavid <daviddavid> 0.22.0-1.mga8
+ Revision: 1583405
- new version: 0.22.0
- now libmajor is 7

* Mon Apr 20 2020 daviddavid <daviddavid> 0.21.0-1.mga8
+ Revision: 1570055
- new version: 0.21.0
- now libmajor is 6

* Thu Mar 12 2020 daviddavid <daviddavid> 0.20.2-1.mga8
+ Revision: 1555657
- new version: 0.20.2

* Tue Feb 25 2020 daviddavid <daviddavid> 0.20.1-1.mga8
+ Revision: 1550202
- new version: 0.20.1

* Tue Feb 18 2020 umeabot <umeabot> 0.20.0-2.mga8
+ Revision: 1541125
- Mageia 8 Mass Rebuild

* Fri Feb 14 2020 daviddavid <daviddavid> 0.20.0-1.mga8
+ Revision: 1521126
- new version: 0.20.0
- now libmajor is 4
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Dec 20 2019 daviddavid <daviddavid> 0.19.3-1.mga8
+ Revision: 1469183
- new version: 0.19.3
- now libmajor is 3
- new version: 0.19.2

* Fri Nov 15 2019 daviddavid <daviddavid> 0.19.1-1.mga8
+ Revision: 1460609
- new version: 0.19.1
- now libmajor is 2

* Fri Nov 08 2019 daviddavid <daviddavid> 0.19.0-1.mga8
+ Revision: 1458735
- new version: 0.19.0

* Tue Oct 01 2019 daviddavid <daviddavid> 0.18.2-2.mga8
+ Revision: 1448570
- rebuild for new nettle 3.5.1

* Mon Sep 16 2019 daviddavid <daviddavid> 0.18.2-1.mga8
+ Revision: 1442336
- new version: 0.18.2

* Mon Aug 19 2019 daviddavid <daviddavid> 0.18.1-1.mga8
+ Revision: 1429912
- new version: 0.18.1

* Fri Aug 02 2019 daviddavid <daviddavid> 0.18.0-1.mga8
+ Revision: 1426907
- new version: 0.18.0

* Sun Jun 30 2019 daviddavid <daviddavid> 0.17.1-1.mga8
+ Revision: 1416256
- new version: 0.17.1

* Tue Apr 30 2019 daviddavid <daviddavid> 0.16.0-1.mga7
+ Revision: 1395938
- new version: 0.16.0

* Tue Nov 27 2018 daviddavid <daviddavid> 0.15.1-1.mga7
+ Revision: 1335894
- new version: 0.15.1

* Fri Oct 19 2018 daviddavid <daviddavid> 0.15.0-1.mga7
+ Revision: 1322595
- new version: 0.15.0

* Fri Oct 05 2018 daviddavid <daviddavid> 0.14.0-1.mga7
+ Revision: 1317905
- new version: 0.14.0

* Fri Sep 21 2018 daviddavid <daviddavid> 0.13.2-1.mga7
+ Revision: 1294963
- new version: 0.13.2

* Mon Sep 17 2018 daviddavid <daviddavid> 0.13.1-1.mga7
+ Revision: 1259385
- new version: 0.13.1

* Tue Jul 17 2018 daviddavid <daviddavid> 0.13.0-1.mga7
+ Revision: 1244088
- new version: 0.13.0

* Mon Jun 11 2018 daviddavid <daviddavid> 0.12.3-1.mga7
+ Revision: 1236306
- new version: 0.12.3

* Tue May 08 2018 daviddavid <daviddavid> 0.12.2-1.mga7
+ Revision: 1227592
- new version: 0.12.2

* Fri Feb 23 2018 daviddavid <daviddavid> 0.12.1-1.mga7
+ Revision: 1204395
- new version: 0.12.1

* Tue Feb 20 2018 daviddavid <daviddavid> 0.12.0-1.mga7
+ Revision: 1203618
- new version: 0.12.0

* Fri Jan 05 2018 daviddavid <daviddavid> 0.11.2-1.mga7
+ Revision: 1190526
- new version: 0.11.2

* Tue Nov 07 2017 daviddavid <daviddavid> 0.11.1-1.mga7
+ Revision: 1176327
- new version: 0.11.1

* Thu Oct 05 2017 daviddavid <daviddavid> 0.11.0-1.mga7
+ Revision: 1169013
- new version: 0.11.0

* Wed Aug 23 2017 daviddavid <daviddavid> 0.10.1-1.mga7
+ Revision: 1143575
- new version: 0.10.1

* Wed Jul 19 2017 daviddavid <daviddavid> 0.10.0-1.mga7
+ Revision: 1124967
- new version: 0.10.0
- remove merged upstream patch

* Sun Jun 04 2017 akien <akien> 0.9.2-3.mga6
+ Revision: 1106526
- Apply previously added patch

* Sun Jun 04 2017 akien <akien> 0.9.2-2.mga6
+ Revision: 1106513
- Add upstream patch to fix filezilla build issue (undefined ref to fz::random_bytes)

* Sat Jun 03 2017 akien <akien> 0.9.2-1.mga6
+ Revision: 1105979
- Version 0.9.2

* Wed Apr 26 2017 akien <akien> 0.9.1-1.mga6
+ Revision: 1097508
- Version 0.9.1

* Wed Dec 14 2016 daviddavid <daviddavid> 0.9.0-1.mga6
+ Revision: 1074970
- new version: 0.9.0

* Tue Nov 01 2016 daviddavid <daviddavid> 0.8.0-1.mga6
+ Revision: 1064456
- new version: 0.8.0

* Fri Oct 14 2016 daviddavid <daviddavid> 0.7.1-2.mga6
+ Revision: 1060780
- rebuild for ARM

* Sat Oct 08 2016 daviddavid <daviddavid> 0.7.1-1.mga6
+ Revision: 1059504
- new version: 0.7.1

* Sun Oct 02 2016 daviddavid <daviddavid> 0.7.0-1.mga6
+ Revision: 1058082
- new version: 0.7.0

* Wed Jul 27 2016 daviddavid <daviddavid> 0.6.1-1.mga6
+ Revision: 1043806
- new version: 0.6.1

* Fri May 27 2016 daviddavid <daviddavid> 0.5.2-1.mga6
+ Revision: 1018954
- new version: 0.5.2

* Mon May 09 2016 daviddavid <daviddavid> 0.5.1-1.mga6
+ Revision: 1011534
- new version: 0.5.1

* Sat Apr 23 2016 daviddavid <daviddavid> 0.5.0-1.mga6
+ Revision: 1005758
- new version: 0.5.0

* Sun Feb 28 2016 daviddavid <daviddavid> 0.4.0.1-1.mga6
+ Revision: 980510
- new version: 0.4.0.1

* Sun Jan 31 2016 daviddavid <daviddavid> 0.3.1-1.mga6
+ Revision: 929299
- new version: 0.3.1
- new upstream snapshot: 0.3.0_rev7291
- enable testsuite
- remove merged upstream patch

* Sat Jan 30 2016 daviddavid <daviddavid> 0.3.0-2.mga6
+ Revision: 929212
- add patch0 to fix linking issue:
  * https://trac.filezilla-project.org/ticket/10734#ticket

* Sat Jan 30 2016 daviddavid <daviddavid> 0.3.0-1.mga6
+ Revision: 929202
- initial package libfilezilla

